@@ -612,7 +612,7 @@ class Youtube(SeleniumUploaderAccount):
             title_field.send_keys(title[:MAX_TITLE_CHAR_LEN])
             self.print('Upload: added title')
             description_container = self.browser.find_by('ytcp-mention-textbox', class_='description-textarea style-scope ytcp-uploads-basics') or self.browser.find(By.XPATH, "/html/body/ytcp-uploads-dialog/paper-dialog/div/ytcp-animatable[1]/ytcp-uploads-details/div/ytcp-uploads-basics/ytcp-mention-textbox[2]")
-            description_field = self.browser.find(By.ID, "textbox", element=description_container)
+            description_field = self.browser.find_by(id='textbox', in_element=description_container)
             description_field.click()
             time.sleep(0.5)
             description_field.clear()
@@ -633,7 +633,7 @@ class Youtube(SeleniumUploaderAccount):
             self.print("Upload: clicked more options")
 
             if tags:
-                tags_container = self.browser.find(By.XPATH, "/html/body/ytcp-uploads-dialog/paper-dialog/div/ytcp-animatable[1]/ytcp-uploads-details/div/ytcp-uploads-advanced/ytcp-form-input-container/div[1]/div[2]/ytcp-free-text-chip-bar/ytcp-chip-bar/div")
+                tags_container = self.browser.find_by('ytcp-form-input-container', id='tags-container') or self.browser.find(By.XPATH, "/html/body/ytcp-uploads-dialog/paper-dialog/div/ytcp-animatable[1]/ytcp-uploads-details/div/ytcp-uploads-advanced/ytcp-form-input-container/div[1]/div[2]/ytcp-free-text-chip-bar/ytcp-chip-bar/div")
                 tags_field = self.browser.find(By.ID, 'text-input', tags_container)
                 tags_field.send_keys(','.join([t for t in tags if len(t) <= MAX_TAG_CHAR_LEN])[:MAX_TAGS_CHAR_LEN-1] + ',')
                 self.print("Upload: added tags")
@@ -649,6 +649,12 @@ class Youtube(SeleniumUploaderAccount):
             self.browser.find(By.ID, 'next-button').click()
             self.print('Upload: clicked second next')
 
+            third_next = self.browser.find_by('ytcp-button', id='next-button')
+
+            if third_next:
+                third_next.click()
+                self.print('Upload: clicked third next')
+
             visibility_main_button = self.browser.find(By.NAME, visibility.name)
             self.browser.find(By.ID, 'radioLabel', visibility_main_button).click()
             self.print('Upload: set to', visibility.name)
